//
//  SCAdSlotController.h
//  Spotx_sdk_ios
//
//  Copyright © 2018 smartclip. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "SCAdPlayerEvent.h"

@class SCAdInfo, SCAdConfiguration, SCPublicAdSlot, SCAdError;
@protocol SCOmidEventLoggingDelegate;

NS_ASSUME_NONNULL_BEGIN

/// Completionblock that delivers an SCAdInfo object
typedef void (^SCAdInfoCompletionBlock)(SCAdInfo* _Nullable adInfo);
/// Completionblock that delivers an SCPublicAdSlot object
typedef void (^SCPublicAdSlotCompletionBlock)(SCPublicAdSlot* _Nullable adInfo);
/// Completionblock that delivers a String as result
typedef void (^SCStringResultCompletionBlock)(NSString* _Nullable result);
/// Completionblock that delivers an AdError object as result
typedef void (^SCAdErrorCompletionBlock)(SCAdError* _Nullable adError);
/**
 * The SCAdSlotController initializes and controls a single AdSlot.
 * A valid SCAdSlotController must be inialized from the SCAdSessionController.
 */
@interface SCAdSlotController : NSObject
/**
 * You start the playback of an ad slot with this function
 * - Parameter configutation: An instance of SCAdConfiguration
 */
- (void)startAdSlotWith:(SCAdConfiguration*)configuration;

///Call this function if you want to stop and active adSlot (before it ends by itself)
- (void)stopAdSlot;

///Call this function if you want to skip an adSlot
- (void)skipAd;

///Cleanup after usage!
- (void)cleanup;

///Callback function for the video player that must be called for certain player events
- (void)playerEventCallbackWith:(SCAdPlayerEventType)playerEventType;

///Call this function for a more detailed adInfo
- (void)getAdInfo:(SCAdInfoCompletionBlock)completion;

///Call this function for a more detailed adInfo
- (void)getPublicAdSlot:(SCPublicAdSlotCompletionBlock)completion;

///Call this function when the user taps on the adView and clickthrough is active
- (void)onClickThrough;

///Add your adView for visibility checks with this function
- (void)addVisibilityCheckerForView:(UIView*)adView;

///Register any view, that covers your adView but belongs to your ad playback views (like soundButton, replayButton etc.)
- (void)registerFriendlyViews:(NSMutableArray*)friendlyViews;

///Call this function if you want to pause playback
- (void)pausePlayback;

///Call this function if you want to start/resume playback
- (void)startPlayback;

///Add views that belong to the player (like soundbuttons etc.) and should not
///be registered as views that cover the adView
- (void)setFriendlyViews:(NSMutableArray*)friendlyViews;

///Call this function, if while streaming an ad the player stops due to an empty buffer
- (void)onBufferEmpty;

///Call this function, if the player can continue after the buffer was empty and is
///able to play on now
- (void)onBufferRefilled;

///Call this function for a detailed adError error description
- (void)getAdError:(SCAdErrorCompletionBlock)completion;

/// :nodoc:
- (void)setOmidEventLoggingDelegate:(id<SCOmidEventLoggingDelegate>)omidEventLogger;

- (void)loadAdSuccess;

- (void)loadAdFailure;
@end

NS_ASSUME_NONNULL_END
